#[repr(transparent)]pub struct Session {
inner: TypedObjectRef<Session, <Session as ObjectSubclass>::ParentType>,
phantom: PhantomData<()>,
}Expand description
A Matrix user session.
GLib type: GObject with reference counted clone semantics.
Fields
inner: TypedObjectRef<Session, <Session as ObjectSubclass>::ParentType>phantom: PhantomData<()>Implementations
Sourceimpl Session
impl Session
The list model of the sidebar.
Sourcepub fn state(&self) -> <Cell<SessionState> as Property>::Value
pub fn state(&self) -> <Cell<SessionState> as Property>::Value
The current state of the session.
Sourcepub fn is_homeserver_reachable(&self) -> <Cell<bool> as Property>::Value
pub fn is_homeserver_reachable(&self) -> <Cell<bool> as Property>::Value
Whether this session has a connection to the homeserver.
Sourcepub fn is_offline(&self) -> <Cell<bool> as Property>::Value
pub fn is_offline(&self) -> <Cell<bool> as Property>::Value
Whether this session is synchronized with the homeserver.
Sourcepub fn settings(&self) -> <OnceCell<SessionSettings> as Property>::Value
pub fn settings(&self) -> <OnceCell<SessionSettings> as Property>::Value
The current settings for this session.
Sourcepub fn global_account_data(
&self,
) -> <OnceCell<GlobalAccountData> as Property>::Value
pub fn global_account_data( &self, ) -> <OnceCell<GlobalAccountData> as Property>::Value
The settings in the global account data for this session.
Sourcepub fn notifications(&self) -> <Notifications as Property>::Value
pub fn notifications(&self) -> <Notifications as Property>::Value
The notifications API for this session.
Sourcepub fn ignored_users(&self) -> <IgnoredUsers as Property>::Value
pub fn ignored_users(&self) -> <IgnoredUsers as Property>::Value
The ignored users API for this session.
Sourcepub fn user_sessions(&self) -> <UserSessionsList as Property>::Value
pub fn user_sessions(&self) -> <UserSessionsList as Property>::Value
The list of sessions for this session’s user.
Sourcepub fn security(&self) -> <SessionSecurity as Property>::Value
pub fn security(&self) -> <SessionSecurity as Property>::Value
Information about security for this session.
Listen for notifications of a change in the sidebar-list-model property
Sourcepub fn connect_user_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_user_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the user property
Sourcepub fn connect_state_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_state_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the state property
Sourcepub fn connect_is_homeserver_reachable_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_is_homeserver_reachable_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the is-homeserver-reachable property
Sourcepub fn connect_is_offline_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_is_offline_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the is-offline property
Sourcepub fn connect_settings_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_settings_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the settings property
Sourcepub fn connect_global_account_data_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_global_account_data_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the global-account-data property
Sourcepub fn connect_notifications_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_notifications_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the notifications property
Sourcepub fn connect_ignored_users_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_ignored_users_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the ignored-users property
Sourcepub fn connect_user_sessions_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_user_sessions_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the user-sessions property
Sourcepub fn connect_security_notify<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub fn connect_security_notify<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Listen for notifications of a change in the security property
Notify listeners of a change in the sidebar-list-model property
Sourcepub fn notify_user(&self)
pub fn notify_user(&self)
Notify listeners of a change in the user property
Sourcepub fn notify_state(&self)
pub fn notify_state(&self)
Notify listeners of a change in the state property
Sourcepub fn notify_is_homeserver_reachable(&self)
pub fn notify_is_homeserver_reachable(&self)
Notify listeners of a change in the is-homeserver-reachable property
Sourcepub fn notify_is_offline(&self)
pub fn notify_is_offline(&self)
Notify listeners of a change in the is-offline property
Sourcepub fn notify_settings(&self)
pub fn notify_settings(&self)
Notify listeners of a change in the settings property
Sourcepub fn notify_global_account_data(&self)
pub fn notify_global_account_data(&self)
Notify listeners of a change in the global-account-data property
Sourcepub fn notify_notifications(&self)
pub fn notify_notifications(&self)
Notify listeners of a change in the notifications property
Sourcepub fn notify_ignored_users(&self)
pub fn notify_ignored_users(&self)
Notify listeners of a change in the ignored-users property
Sourcepub fn notify_user_sessions(&self)
pub fn notify_user_sessions(&self)
Notify listeners of a change in the user-sessions property
Sourcepub fn notify_security(&self)
pub fn notify_security(&self)
Notify listeners of a change in the security property
Sourceimpl Session
impl Session
Sourcepub(crate) async fn new(
stored_session: StoredSession,
settings: SessionSettings,
) -> Result<Self, ClientSetupError>
pub(crate) async fn new( stored_session: StoredSession, settings: SessionSettings, ) -> Result<Self, ClientSetupError>
Construct an existing session.
Sourcepub(crate) async fn create(client: &Client) -> Result<Self, ClientSetupError>
pub(crate) async fn create(client: &Client) -> Result<Self, ClientSetupError>
Create a new session from the session of the given Matrix client.
Sourcepub(crate) fn verification_list(&self) -> VerificationList
pub(crate) fn verification_list(&self) -> VerificationList
The verification list of this session.
Sourcepub(crate) fn remote_cache(&self) -> &RemoteCache
pub(crate) fn remote_cache(&self) -> &RemoteCache
The cache for remote data.
Sourcepub(crate) async fn clean_up(&self)
pub(crate) async fn clean_up(&self)
Clean up this session after it was logged out.
This should only be called if the session has been logged out without
calling Session::log_out.
Sourcepub(crate) fn connect_logged_out<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub(crate) fn connect_logged_out<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Connect to the signal emitted when this session is logged out.
Sourcepub(crate) fn connect_ready<F: Fn(&Self) + 'static>(
&self,
f: F,
) -> SignalHandlerId
pub(crate) fn connect_ready<F: Fn(&Self) + 'static>( &self, f: F, ) -> SignalHandlerId
Connect to the signal emitted when this session is ready.